Method: Array#fetch_objects!

Defined in:
lib/parse/model/core/fetching.rb

#fetch_objects!(lookup = :parallel) ⇒ Array<Parse::Object>

Fetches all the objects in the array even if they are not in a Pointer state.

Parameters:

  • lookup (Symbol) (defaults to: :parallel)

    The methodology to use for HTTP requests. Use :parallel to fetch all objects in parallel HTTP requests. Set to anything else to perform requests serially.

Returns:

See Also:



88
89
90
91
92
93
94
# File 'lib/parse/model/core/fetching.rb', line 88

def fetch_objects!(lookup = :parallel)
  # this gets all valid parse objects from the array
  items = valid_parse_objects
  lookup == :parallel ? items.threaded_each(2,&:fetch!) : items.each(&:fetch!)
  #self.replace items
  self #return for chaining.
end