Method: Parse.config

Defined in:
lib/parse/client.rb

.config(conn = :default) ⇒ Hash

Retrieve the App specific Parse configuration parameters. The configuration for a connection is cached after the first request. Use the bang version to force update from the Parse backend.

Examples:

val = Parse.config["myKey"]
val = Parse.config["myKey"] # cached

Parameters:

  • conn (Symbol) (defaults to: :default)

    the name of the client connection to use.

Returns:

  • (Hash)

    the Parse config hash for the session.

See Also:



57
58
59
# File 'lib/parse/client.rb', line 57

def self.config(conn = :default)
  Parse::Client.client(conn).config
end