Method: Parse::Core::Actions#op_add!

Defined in:
lib/parse/model/core/actions.rb

#op_add!(field, objects) ⇒ Boolean

Perform an atomic add operation to the array field.

Parameters:

  • field (String)

    the name of the field in the Parse collection.

  • objects (Array)

    the set of items to add to this field.

Returns:

  • (Boolean)

    whether it was successful

See Also:



310
311
312
# File 'lib/parse/model/core/actions.rb', line 310

def op_add!(field,objects)
  operate_field! field, { __op: :Add, objects: objects }
end