Method: Parse::Query#compile_where

Defined in:
lib/parse/query.rb

#compile_whereHash

Returns a hash representing just the where clause of this query.

Returns:

  • (Hash)

    a hash representing just the where clause of this query.



849
850
851
# File 'lib/parse/query.rb', line 849

def compile_where
  self.class.compile_where( @where || [] )
end