Method: Parse::User.signup

Defined in:
lib/parse/model/classes/user.rb

.signup(username, password, email = nil, body: {}) ⇒ Object

This method will signup a new user using the parameters below. The required fields to create a user in Parse is the username and password fields. The email field is optional. Both username and email (if provided), must be unique. At a minimum, it is recommended you perform a query using the supplied username first to verify do not already have an account with that username. This method will raise all the exceptions from the similar create method.

See Also:



366
367
368
369
370
# File 'lib/parse/model/classes/user.rb', line 366

def self.(username, password, email = nil, body: {})
  body = body.merge({username: username, password: password })
  body[:email] = email if email.present?
  self.create(body)
end