Method: Parse.config
- Defined in:
- lib/parse/client.rb
.config(conn = :default) ⇒ Hash
Retrieve the App specific Parse configuration parameters. The configuration for a connection is cached after the first request. Use the bang version to force update from the Parse backend.
57 58 59 |
# File 'lib/parse/client.rb', line 57 def self.config(conn = :default) Parse::Client.client(conn).config end |