Method: Parse::Query#session_token
- Defined in:
- lib/parse/query.rb
#session_token ⇒ String
Note:
Using a session_token automatically disables sending the master key in the request.
Set the session token to send with this API request. A session token is tied to a logged in User. When sending a session_token in the request, this performs the query on behalf of the user (with their allowed privileges). Using the short hand (inline) form, you can also pass an authenticated User instance or a Session instance.
152 |
# File 'lib/parse/query.rb', line 152 attr_accessor :table, :client, :key, :cache, :use_master_key, :session_token |